@@ -6,13 +6,13 @@
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 import asyncio
-import json
 from dataclasses import dataclass, field
 from typing import Literal, Any
 
 import mistune
 
-from .utils import assert_string_match_pattern, print_string_match_pattern
+from run_markdown.json_comparator import JsonComparator
+from run_markdown.text_comparator import TextComparator
 
 
 @dataclass
@@ -110,17 +110,14 @@ class Check:
         print(' ' * depth + f'Got {preview(actual)}... ', end='')
         if expected:
             if self.expected_format == 'json':
-                expected = json.loads(expected)
-                actual = json.loads(actual)
+                comparator = JsonComparator(expected)
             else:
-                expected = expected.strip().replace('\r', '')
-                actual = actual.strip().replace('\r', '')
-            try:
-                assert_string_match_pattern(pattern=expected, string=actual)
-            except ValueError:
-                print('FAIL: ')
-                print_string_match_pattern(pattern=expected, string=actual, depth=depth)
-                raise
+                comparator = TextComparator(expected)
+            comparison_result = comparator.compare(actual)
+            if comparison_result.exception is not None:
+                print('ERROR')
+                comparison_result.print()
+                raise comparison_result.exception
             else:
                 print('OK')
         else:
